#!/bin/bash

DISTRIBUTION=${DISTRIBUTION:-noble}
REVISION=${REVISION:-1}

rm -rf output
rm -rf *.whl
rm wheel2deb.yml

# Download latest weels
python3 -m pip wheel PySide6-Essentials
python3 -m pip wheel PySide6-Addons

# Create wheel for distribution
cp wheel2deb.src.yml wheel2deb.yml
sed -i -e "s/\\[DIST\\]/$DISTRIBUTION/g" wheel2deb.yml

wheel2deb convert -c ./wheel2deb.yml

echo -e "\n[Writing modifications]\n"

for i in output/*; do
    cp copyright "$i/debian" # Add copyrights
    perl -i -p0e 's/python3 \(<< 3.(\d)+\),//gm' "$i/debian/control" # Remove upper limit from control.
    sed -i "s/stable;/$DISTRIBUTION;/g" "$i/debian/changelog" # Change distribution.
    sed -i "s/1~w2d0/$REVISION/g" "$i/debian/changelog" # Change suffix
    mv "$i" "${i/1~w2d0/$REVISION}"
done

# Moving the shaders library over to essentials since it's required by Qt5Compat
mv output/python3-pyside6-addons_*_amd64/src/PySide6/Qt/lib/libQt6ShaderTools.so.6 output/python3-pyside6-essentials_*_amd64/src/PySide6/Qt/lib/

# Remove conflicting files between Essentials and Addons
rm output/python3-pyside6-addons_*_amd64/src/PySide6/{__init__.py,_config.py,_git_pyside_version.py}
rm -r output/python3-pyside6-addons_*_amd64/src/PySide6/{QtAsyncio,support,scripts}

# Removing conflictual directories
rm -rf output/python3-pyside6-addons_*_amd64/src/shiboken6*
rm -rf output/python3-pyside6-essentials_*_amd64/src/shiboken6*
rm -rf output/python3-shiboken6_*_amd64/src/PySide6

function filter() { cat "$1" | awk "$2" > "$1"; }

filter output/python3-shiboken6_*_amd64/debian/install '/^src\/shiboken6/ { print $0; }'
filter output/python3-pyside6-essentials_*_amd64/debian/install '/^src\/PySide6/ { print $0; }'
filter output/python3-pyside6-addons_*_amd64/debian/install '/^src\/PySide6/ { print $0; }'
